import Vue from 'vue'
import router from '@/router'
import { v4 as uuidv4 } from 'uuid';

export const download_blob = (blob: Blob, filename: string) => {
  // 创建一个 a 标签
  const link = document.createElement("a")
  // 一个 URL，可以是任意协议的，不只是 HTTP 协议
  // 这里创建了一个 Blob URL
  link.href = URL.createObjectURL(blob)
  console.log("Blob URL:", link.href)

  // 去除不可用的字符
  const filename_escaped = filename.replace(/[\\\/:\*\?"<>\|]/g, "").trim()

  link.download = filename_escaped
  link.click()
  // 需要释放 URL
  URL.revokeObjectURL(link.href)
  link.remove()
}

/**
 * 获取uuid
 */
export function getUUID(): string {
  return uuidv4();
}

/**
 * 是否有权限
 * @param {*} key
 */
export function isAuth(key: string): boolean {
  let authorities = JSON.parse(sessionStorage.getItem('authorities') || '[]')
  if (authorities.length) {
    for (const i in authorities) {
      const element = authorities[i]
      if (element === key) {
        return true
      }
    }
  }
  return false
}

/**
 * 清除登录信息
 */
export function clearLoginInfo() {
  //@ts-ignore
  Vue.cookie.delete('Authorization')
  //@ts-ignore
  router.options.isAddDynamicMenuRoutes = false
}
